// Copyright (C) 2015 the V8 project authors. All rights reserved.
// This code is governed by the BSD license found in the LICENSE file.
/*---
esid: sec-set.prototype.add
description: >
    Set.prototype.add ( value )

    ...
    3. If S does not have a [[SetData]] internal slot, throw a TypeError exception.
    ...

---*/

assert.throws(TypeError, function() {
  Set.prototype.add.call(Set.prototype, 1);
});

assert.throws(TypeError, function() {
  var s = new Set();
  s.add.call(Set.prototype, 1);
});

reportCompare(0, 0);
